==> eam-wshub-proxyclient-11.4-4-sources.jar: net/datastream/schemas/mp_functions/mp0415_001/MP0415_SyncPurchaseOrder_001.java <==

package net.datastream.schemas.mp_functions.mp0415_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.purchaseorder_001.PurchaseOrder;
import net.datastream.schemas.mp_fields.BaseSchemaRequestElement;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;extension base="{http://schemas.datastream.net/MP_fields}BaseSchemaRequestElement">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/PurchaseOrder_001}PurchaseOrder"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Sync" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="PurchaseOrder" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       &lt;attribute name="confirm_suppref_varies" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="not_needed" />
 *       &lt;attribute name="confirm_supplierpolimit" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="not_needed" />
 *       &lt;attribute name="confirm_cancel_reqlines" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="not_needed" />
 *       &lt;attribute name="confirm_unfinish_polines" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="not_needed" />
 *       &lt;attribute name="confirm_cancel_polines" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="not_needed" />
 *       &lt;attribute name="is_batchpo" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "purchaseOrder"
})
@XmlRootElement(name = "MP0415_SyncPurchaseOrder_001")
public class MP0415_SyncPurchaseOrder_001
    extends BaseSchemaRequestElement
{

    @XmlElement(name = "PurchaseOrder", namespace = "http://schemas.datastream.net/MP_entities/PurchaseOrder_001", required = true)
    protected PurchaseOrder purchaseOrder;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "confirm_suppref_varies")
    protected String confirm_Suppref_Varies;
    @XmlAttribute(name = "confirm_supplierpolimit")
    protected String confirm_Supplierpolimit;
    @XmlAttribute(name = "confirm_cancel_reqlines")
    protected String confirm_Cancel_Reqlines;
    @XmlAttribute(name = "confirm_unfinish_polines")
    protected String confirm_Unfinish_Polines;
    @XmlAttribute(name = "confirm_cancel_polines")
    protected String confirm_Cancel_Polines;
    @XmlAttribute(name = "is_batchpo")
    protected Boolean is_Batchpo;

    /**
     * Obtient la valeur de la propriété purchaseOrder.
     * 
     * @return
     *     possible object is
     *     {@link PurchaseOrder }
     *     
     */
    public PurchaseOrder getPurchaseOrder() {
        return purchaseOrder;
    }

    /**
     * Définit la valeur de la propriété purchaseOrder.
     * 
     * @param value
     *     allowed object is
     *     {@link PurchaseOrder }
     *     
     */
    public void setPurchaseOrder(PurchaseOrder value) {
        this.purchaseOrder = value;
    }

    /**
     * Obtient la valeur de la propriété verb.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.SYNC;
        } else {
            return verb;
        }
    }

    /**
     * Définit la valeur de la propriété verb.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Obtient la valeur de la propriété noun.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.PURCHASE_ORDER;
        } else {
            return noun;
        }
    }

    /**
     * Définit la valeur de la propriété noun.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Obtient la valeur de la propriété version.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Définit la valeur de la propriété version.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Obtient la valeur de la propriété confirm_Suppref_Varies.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Suppref_Varies() {
        if (confirm_Suppref_Varies == null) {
            return "not_needed";
        } else {
            return confirm_Suppref_Varies;
        }
    }

    /**
     * Définit la valeur de la propriété confirm_Suppref_Varies.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Suppref_Varies(String value) {
        this.confirm_Suppref_Varies = value;
    }

    /**
     * Obtient la valeur de la propriété confirm_Supplierpolimit.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Supplierpolimit() {
        if (confirm_Supplierpolimit == null) {
            return "not_needed";
        } else {
            return confirm_Supplierpolimit;
        }
    }

    /**
     * Définit la valeur de la propriété confirm_Supplierpolimit.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Supplierpolimit(String value) {
        this.confirm_Supplierpolimit = value;
    }

    /**
     * Obtient la valeur de la propriété confirm_Cancel_Reqlines.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Cancel_Reqlines() {
        if (confirm_Cancel_Reqlines == null) {
            return "not_needed";
        } else {
            return confirm_Cancel_Reqlines;
        }
    }

    /**
     * Définit la valeur de la propriété confirm_Cancel_Reqlines.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Cancel_Reqlines(String value) {
        this.confirm_Cancel_Reqlines = value;
    }

    /**
     * Obtient la valeur de la propriété confirm_Unfinish_Polines.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Unfinish_Polines() {
        if (confirm_Unfinish_Polines == null) {
            return "not_needed";
        } else {
            return confirm_Unfinish_Polines;
        }
    }

    /**
     * Définit la valeur de la propriété confirm_Unfinish_Polines.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Unfinish_Polines(String value) {
        this.confirm_Unfinish_Polines = value;
    }

    /**
     * Obtient la valeur de la propriété confirm_Cancel_Polines.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Cancel_Polines() {
        if (confirm_Cancel_Polines == null) {
            return "not_needed";
        } else {
            return confirm_Cancel_Polines;
        }
    }

    /**
     * Définit la valeur de la propriété confirm_Cancel_Polines.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Cancel_Polines(String value) {
        this.confirm_Cancel_Polines = value;
    }

    /**
     * Obtient la valeur de la propriété is_Batchpo.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isIs_Batchpo() {
        return is_Batchpo;
    }

    /**
     * Définit la valeur de la propriété is_Batchpo.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIs_Batchpo(Boolean value) {
        this.is_Batchpo = value;
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_functions/mp0415_001/MP0415_SyncPurchaseOrder_001.java <==

package net.datastream.schemas.mp_functions.mp0415_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.purchaseorder_001.PurchaseOrder;
import net.datastream.schemas.mp_fields.BaseSchemaRequestElement;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <extension base="{http://schemas.datastream.net/MP_fields}BaseSchemaRequestElement">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_entities/PurchaseOrder_001}PurchaseOrder"/>
 *       </sequence>
 *       <attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Sync" />
 *       <attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="PurchaseOrder" />
 *       <attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       <attribute name="confirm_suppref_varies" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="not_needed" />
 *       <attribute name="confirm_supplierpolimit" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="not_needed" />
 *       <attribute name="confirm_cancel_reqlines" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="not_needed" />
 *       <attribute name="confirm_unfinish_polines" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="not_needed" />
 *       <attribute name="confirm_cancel_polines" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="not_needed" />
 *       <attribute name="is_batchpo" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "purchaseOrder"
})
@XmlRootElement(name = "MP0415_SyncPurchaseOrder_001")
public class MP0415_SyncPurchaseOrder_001
    extends BaseSchemaRequestElement
{

    @XmlElement(name = "PurchaseOrder", namespace = "http://schemas.datastream.net/MP_entities/PurchaseOrder_001", required = true)
    protected PurchaseOrder purchaseOrder;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "confirm_suppref_varies")
    protected String confirm_Suppref_Varies;
    @XmlAttribute(name = "confirm_supplierpolimit")
    protected String confirm_Supplierpolimit;
    @XmlAttribute(name = "confirm_cancel_reqlines")
    protected String confirm_Cancel_Reqlines;
    @XmlAttribute(name = "confirm_unfinish_polines")
    protected String confirm_Unfinish_Polines;
    @XmlAttribute(name = "confirm_cancel_polines")
    protected String confirm_Cancel_Polines;
    @XmlAttribute(name = "is_batchpo")
    protected Boolean is_Batchpo;

    /**
     * Gets the value of the purchaseOrder property.
     * 
     * @return
     *     possible object is
     *     {@link PurchaseOrder }
     *     
     */
    public PurchaseOrder getPurchaseOrder() {
        return purchaseOrder;
    }

    /**
     * Sets the value of the purchaseOrder property.
     * 
     * @param value
     *     allowed object is
     *     {@link PurchaseOrder }
     *     
     */
    public void setPurchaseOrder(PurchaseOrder value) {
        this.purchaseOrder = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.SYNC;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.PURCHASE_ORDER;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Gets the value of the confirm_Suppref_Varies property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Suppref_Varies() {
        if (confirm_Suppref_Varies == null) {
            return "not_needed";
        } else {
            return confirm_Suppref_Varies;
        }
    }

    /**
     * Sets the value of the confirm_Suppref_Varies property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Suppref_Varies(String value) {
        this.confirm_Suppref_Varies = value;
    }

    /**
     * Gets the value of the confirm_Supplierpolimit property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Supplierpolimit() {
        if (confirm_Supplierpolimit == null) {
            return "not_needed";
        } else {
            return confirm_Supplierpolimit;
        }
    }

    /**
     * Sets the value of the confirm_Supplierpolimit property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Supplierpolimit(String value) {
        this.confirm_Supplierpolimit = value;
    }

    /**
     * Gets the value of the confirm_Cancel_Reqlines property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Cancel_Reqlines() {
        if (confirm_Cancel_Reqlines == null) {
            return "not_needed";
        } else {
            return confirm_Cancel_Reqlines;
        }
    }

    /**
     * Sets the value of the confirm_Cancel_Reqlines property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Cancel_Reqlines(String value) {
        this.confirm_Cancel_Reqlines = value;
    }

    /**
     * Gets the value of the confirm_Unfinish_Polines property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Unfinish_Polines() {
        if (confirm_Unfinish_Polines == null) {
            return "not_needed";
        } else {
            return confirm_Unfinish_Polines;
        }
    }

    /**
     * Sets the value of the confirm_Unfinish_Polines property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Unfinish_Polines(String value) {
        this.confirm_Unfinish_Polines = value;
    }

    /**
     * Gets the value of the confirm_Cancel_Polines property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Cancel_Polines() {
        if (confirm_Cancel_Polines == null) {
            return "not_needed";
        } else {
            return confirm_Cancel_Polines;
        }
    }

    /**
     * Sets the value of the confirm_Cancel_Polines property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Cancel_Polines(String value) {
        this.confirm_Cancel_Polines = value;
    }

    /**
     * Gets the value of the is_Batchpo property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isIs_Batchpo() {
        return is_Batchpo;
    }

    /**
     * Sets the value of the is_Batchpo property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIs_Batchpo(Boolean value) {
        this.is_Batchpo = value;
    }

}
